@@ -78,3 +78,10 @@ cad.ArAr <- function(x,pch=NA,verticals=TRUE,
     tt <- ArAr.age(x)[,1]
     cad.default(tt,pch=pch,verticals=verticals,xlab=xlab,col=col,...)
 }
+#' @rdname cad
+#' @export
+cad.UThHe <- function(x,pch=NA,verticals=TRUE,
+                      xlab='age [Ma]',col='black',...){
+    tt <- UThHe.age(x)[,1]
+    cad.default(tt,pch=pch,verticals=verticals,xlab=xlab,col=col,...)
+}
