@@ -157,6 +157,19 @@ kde.ArAr <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
                 show.hist=show.hist,bty=bty,binwidth=binwidth,
                 ncol=ncol,...)
 }
+#' @rdname kde
+#' @export
+kde.UThHe <- function(x,from=NA,to=NA,bw=NA,adaptive=TRUE,log=FALSE,
+                      n=512,plot=TRUE,pch=NA,xlab="age [Ma]",ylab="",
+                      kde.col=rgb(1,0,1,0.6),hist.col=rgb(0,1,0,0.2),
+                      show.hist=TRUE,bty='n',binwidth=NA,ncol=NA,...){
+    tt <- UThHe.age(x)[,1]
+    kde.default(tt,from=from,to=to,bw=bw,adaptive=adaptive,log=log,
+                n=n,plot=plot,pch=pch,xlab=xlab,ylab=ylab,
+                kde.col=kde.col, hist.col=hist.col,
+                show.hist=show.hist,bty=bty,binwidth=binwidth,
+                ncol=ncol,...)
+}
 
 # helper functions for the generic kde function
 getkde <- function(x,...){ UseMethod("getkde",x) }
